@@ -6,6 +6,7 @@ from geoalchemy2.types import Geometry
 from geoalchemy2.elements import (
     WKTElement, WKBElement, RasterElement, CompositeElement
 )
+from geoalchemy2.compat import str as str_
 
 
 @pytest.fixture
@@ -37,6 +38,15 @@ class TestWKTElement():
             u'ST_GeomFromText_2': -1
         }
 
+    def test_pickle_unpickle(self):
+        import pickle
+        e = WKTElement('POINT(1 2)', srid=3, extended=True)
+        pickled = pickle.dumps(e)
+        unpickled = pickle.loads(pickled)
+        assert unpickled.srid == 3
+        assert unpickled.extended is True
+        assert unpickled.data == 'POINT(1 2)'
+
 
 class TestExtendedWKTElement():
 
@@ -115,6 +125,10 @@ class TestWKBElement():
         e = WKBElement(b'\x01\x02', extended=True)
         assert e.desc == '0102'
 
+    def test_desc_str(self):
+        e = WKBElement(str_('0102'))
+        assert e.desc == str_('0102')
+
     def test_function_call(self):
         e = WKBElement(b'\x01\x02', extended=True)
         f = e.ST_Buffer(2)
@@ -130,6 +144,15 @@ class TestWKBElement():
         e = WKBElement(b'\x01\x02', extended=True)
         assert isinstance(str(e), str)
 
+    def test_pickle_unpickle(self):
+        import pickle
+        e = WKBElement(b'\x01\x02', srid=3, extended=True)
+        pickled = pickle.dumps(e)
+        unpickled = pickle.loads(pickled)
+        assert unpickled.srid == 3
+        assert unpickled.extended is True
+        assert unpickled.data == b'\x01\x02'
+
 
 class TestExtendedWKBElement():
 
